﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Linq;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace ChartswithSyncfusion
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class BlankPage1 : Page
    {
        public IList<Test> ItemsList { get; set; }

        public BlankPage1()
        {
            this.InitializeComponent();
            ItemsList = new List<Test>();
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            var items = e.Parameter as List<Test>;
            if (items != null && items.Count > 0)
            {
                foreach (var item in items)
                    ItemsList.Add(item);
                GenerateChartDesign();
            }

            //var text = e.Parameter as string;
            //testTb.Text = text;
        }

        private void GenerateChartDesign()
        {
            PieSeries pieChart = new PieSeries();
            DataTemplate template1 = MainGrid.Resources["labelTemplate"] as DataTemplate;
            ChartAdornmentInfo adornment = new ChartAdornmentInfo();
            adornment.ShowLabel = true;
            pieChart.XBindingPath = "Name";
            pieChart.YBindingPath = "Value";
            pieChart.ItemsSource = ItemsList;
            pieChart.ConnectorType = ConnectorMode.Bezier;
            pieChart.PieCoefficient = 0.7;
            pieChart.LabelPosition = CircularSeriesLabelPosition.OutsideExtended;
            adornment.LabelTemplate = template1;
            adornment.AdornmentsPosition = AdornmentsPosition.Bottom;
            adornment.HorizontalAlignment = Windows.UI.Xaml.HorizontalAlignment.Center;
            adornment.VerticalAlignment = Windows.UI.Xaml.VerticalAlignment.Center;
            adornment.UseSeriesPalette = true;
            pieChart.AdornmentsInfo = adornment;

            SfChart chartRegion = new SfChart();
            chartRegion.Series.Clear();
            chartRegion.Series.Add(pieChart);
            if (MainGrid.Children.Contains(chartRegion))
            {
                MainGrid.Children.Remove(chartRegion);
            }
            chartRegion.Legend = new ChartLegend()
            {
                CornerRadius = new CornerRadius(0),
                FontSize = 16,
                Margin = new Thickness(0, 0, 50, 0),
                BorderThickness = new Thickness(1),
                ItemTemplate = MainGrid.Resources["LegendItemTemplate"] as DataTemplate
            };
        
            chartRegion.HorizontalAlignment = HorizontalAlignment.Center;
            MainGrid.Children.Insert(0, chartRegion);
        }
    }

    public class ColorConverter : IValueConverter
    {
        private SolidColorBrush ApplyLight(SolidColorBrush color)
        {
            return color;
        }

        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if (value != null && (value is ChartAdornment))
            {
                ChartAdornment pieAdornment = value as ChartAdornment;
                int index = pieAdornment.Series.Adornments.IndexOf(pieAdornment);
                SolidColorBrush brush = pieAdornment.Series.ColorModel.GetBrush(index) as SolidColorBrush;
                return ApplyLight(brush);
            }
            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            return value;
        }
    }

    public class LabelConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if (value is ChartAdornment)
            {
                ChartAdornment pieAdornment = value as ChartAdornment;
                return String.Format((pieAdornment.Item as Test).Name);
            }
            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            return value;
        }
    }
}